==> haskell-regex-compat-0.95.2.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-compat
version:              0.95.2.1
visibility:           public
id:                   regex-compat-0.95.2.1-AyC0wJj3rmJIrop9pFbSaj
key:                  regex-compat-0.95.2.1-AyC0wJj3rmJIrop9pFbSaj
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:
    Herbert Valerio Riedel <hvr@gnu.org>,
    Andreas Abel

author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:             Replaces/enhances "Text.Regex"
description:
    One module compat layer over <//hackage.haskell.org/package/regex-posix regex-posix> to replace "Text.Regex".

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  4340fdc2a1eb995808c7ee7ec36f9347
exposed:              True
exposed-modules:      Text.Regex
import-dirs:          /usr/lib/ghc-9.0.1/site-local/regex-compat-0.95.2.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/regex-compat-0.95.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/regex-compat-0.95.2.1
hs-libraries:         HSregex-compat-0.95.2.1-AyC0wJj3rmJIrop9pFbSaj
depends:
    array-0.5.4.0 base-4.15.0.0
    regex-base-0.94.0.1-ApKWahF5a61J2tR7Doeu1C
    regex-posix-0.96.0.1-ICff79JbeoKL4XN6EAg8yK

haddock-interfaces:
    /usr/share/doc/haskell-regex-compat/html/regex-compat.haddock

haddock-html:         /usr/share/doc/haskell-regex-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-compat-0.95.2.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-compat
version:              0.95.2.1
visibility:           public
id:                   regex-compat-0.95.2.1-BYf5MzDvacc20KBqPh3t2u
key:                  regex-compat-0.95.2.1-BYf5MzDvacc20KBqPh3t2u
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:
    Herbert Valerio Riedel <hvr@gnu.org>,
    Andreas Abel

author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:             Replaces/enhances "Text.Regex"
description:
    One module compat layer over <//hackage.haskell.org/package/regex-posix regex-posix> to replace "Text.Regex".

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  153ed61a6554406263aafdde8065b0b0
exposed:              True
exposed-modules:      Text.Regex
import-dirs:          /usr/lib/ghc-9.0.1/site-local/regex-compat-0.95.2.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/regex-compat-0.95.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/regex-compat-0.95.2.1
hs-libraries:         HSregex-compat-0.95.2.1-BYf5MzDvacc20KBqPh3t2u
depends:
    array-0.5.4.0 base-4.15.0.0
    regex-base-0.94.0.2-1zsBt75PqJm7HZsEZt0j76
    regex-posix-0.96.0.1-9IaC5NAq1dnF4fUYbtp0yj

haddock-interfaces:
    /usr/share/doc/haskell-regex-compat/html/regex-compat.haddock

haddock-html:         /usr/share/doc/haskell-regex-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
